Module beamlit.models.spec_configuration
========================================

Classes
-------

`SpecConfiguration(secret: beamlit.types.Unset | bool = <beamlit.types.Unset object>, value: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Configuration, this is a key value storage. In your object you can retrieve the value with config[key]
    
    Attributes:
        secret (Union[Unset, bool]): ACconfiguration secret
        value (Union[Unset, str]): Configuration value
    
    Method generated by attrs for class SpecConfiguration.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `secret: beamlit.types.Unset | bool`
    :

    `value: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :